@@ -3,11 +3,21 @@
 #'
 #'   Tessellations on a Linear Network
 #'
-#'   $Revision: 1.7 $   $Date: 2016/07/13 08:13:24 $
+#'   $Revision: 1.12 $   $Date: 2017/02/07 08:12:05 $
 #'
 
 lintess <- function(L, df) {
   verifyclass(L, "linnet")
+  if(missing(df) || is.null(df)) {
+    # tessellation consisting of a single tile
+    ns <- nsegments(L)
+    df <- data.frame(seg=seq_len(ns), t0=0, t1=1, tile=factor(1))
+    out <- list(L=L, df=df)
+    class(out) <- c("lintess", class(out))
+    return(out)
+  } 
+  # validate 'df'
+  stopifnot(is.data.frame(df))
   needed <- c("seg", "t0", "t1", "tile")
   if(any(bad <- is.na(match(needed, colnames(df)))))
     stop(paste(ngettext(sum(bad), "Column", "Columns"),
@@ -36,7 +46,7 @@ lintess <- function(L, df) {
     for(piece in pieces) {
       t0 <- piece$t0
       t1 <- piece$t1
-      thedata <- paste("Data for segment", piece$seg[[1]])
+      thedata <- paste("Data for segment", piece$seg[[1L]])
       if(!any(t0 == 0))
         stop(paste(thedata, "do not contain an entry with t0 = 0"),
              call.=FALSE)
@@ -61,11 +71,56 @@ print.lintess <- function(x, ...) {
   return(invisible(NULL))
 }
 
-plot.lintess <- function(x, ..., main) {
+plot.lintess <- function(x, ..., main, add=FALSE,
+                         style=c("segments", "image"),
+                         col=NULL) {
   if(missing(main)) main <- short.deparse(substitute(x))
-  plot(as.linfun(x), main=main, ...)
+  style <- match.arg(style)
+  if(style == "image") {
+    z <- plot(as.linfun(x), main=main, ..., add=add)
+    return(invisible(z))
+  }
+  #' determine colour map
+  df <- x$df
+  lev <- levels(df$tile)
+  if(is.null(col)) {
+    col <- rainbow(length(lev))
+    cmap <- colourmap(col, inputs=lev)
+  } else if(inherits(col, "colourmap")) {
+    cmap <- col
+    col <- cmap(lev)
+  } else if(is.colour(col)) {
+    if(length(col) == 1) col <- rep(col, length(lev))
+    if(length(col) != length(lev))
+      stop(paste(length(col), "colours provided but",
+                 length(lev), "colours needed"))
+    cmap <- colourmap(col, inputs=lev)
+  } else stop("col should be a vector of colours, or a colourmap object")
+  #' determine segment coordinates
+  L <- as.linnet(x)
+  from <- L$from[df$seg]
+  to   <- L$to[df$seg]
+  V <- vertices(L)
+  vx <- V$x
+  vy <- V$y
+  #' plot
+  if(!add) plot(Frame(x), main=main, type="n")
+  with(df,
+       segments(
+         vx[from] * (1-t0) + vx[to] * t0,
+         vy[from] * (1-t0) + vy[to] * t0,
+         vx[from] * (1-t1) + vx[to] * t1,
+         vy[from] * (1-t1) + vy[to] * t1,
+         col=col[as.integer(tile)],
+         ...)
+       )
+  return(invisible(cmap))
 }
 
+as.owin.lintess <- function(W, ...) { as.owin(as.linnet(W), ...) }
+
+Window.lintess <- function(X, ...) { as.owin(as.linnet(X)) }
+
 as.linnet.lintess <- function(X, ...) { X$L }
 
 as.linfun.lintess <- function(X, ...) {
@@ -125,7 +180,7 @@ divide.linnet <- local({
       njoin <- length(joined)
       if(njoin > 1)
         iedge <- c(iedge, joined[-njoin])
-      jedge <- c(jedge, joined[-1])
+      jedge <- c(jedge, joined[-1L])
     }
     nedge <- length(iedge)
     zz <- .C("cocoGraph",
@@ -134,7 +189,7 @@ divide.linnet <- local({
              ie = as.integer(iedge - 1L),
              je = as.integer(jedge - 1L),
              label = as.integer(integer(nbits)), 
-             status = as.integer(integer(1)))
+             status = as.integer(integer(1L)))
     if (zz$status != 0) 
       stop("Internal error: connectedness algorithm did not converge")
     lab <- zz$label + 1L
@@ -146,13 +201,13 @@ divide.linnet <- local({
 
   expanddata <- function(z) {
     df <- with(z,
-               data.frame(seg=c(seg[1], seg),
+               data.frame(seg=c(seg[1L], seg),
                           t0 = c(0, tp),
                           t1 = c(tp, 1),
                           from=NA_integer_,
                           to=NA_integer_))
-    df$from[1] <- z$from[1]
-    df$to[nrow(df)] <- z$to[1]
+    df$from[1L] <- z$from[1L]
+    df$to[nrow(df)] <- z$to[1L]
     return(df)
   }
 
