@@ -10,9 +10,10 @@ options(useFancyQuotes=FALSE)
 
 
 ###################################################
-### code chunk number 2: updates.Rnw:41-46
+### code chunk number 2: updates.Rnw:41-47
 ###################################################
-z <- read.table("packagesizes.txt", header=TRUE)
+fname <- system.file("doc", "packagesizes.txt", package="spatstat")
+z <- read.table(fname, header=TRUE)
 z$date <- as.Date(z$date)
 changes <- z[nrow(z), ] - z[z$version == "1.42-0", ]
 newobj <- changes[["nobjects"]]
@@ -20,7 +21,7 @@ newdat <- changes[["ndatasets"]] + 1  # counting rule doesn't detect redwood3
 
 
 ###################################################
-### code chunk number 3: updates.Rnw:56-61
+### code chunk number 3: updates.Rnw:57-62
 ###################################################
 options(SweaveHooks=list(fig=function() par(mar=0.2+c(2,4,2,0))))
 Plot <- function(fmla, ..., dat=z) {
@@ -30,7 +31,7 @@ Plot <- function(fmla, ..., dat=z) {
 
 
 ###################################################
-### code chunk number 4: updates.Rnw:67-72
+### code chunk number 4: updates.Rnw:68-73
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 Plot((Rlines + srclines)/1000 ~ date, ylab="Lines of code (x 1000)", 
@@ -41,7 +42,7 @@ text(as.Date("2013-01-01"), 50, "R code")
 
 
 ###################################################
-### code chunk number 5: updates.Rnw:1250-1254
+### code chunk number 5: updates.Rnw:1390-1394
 ###################################################
 nbugs <- nrow(news(grepl("^BUG", Category), 
                    package="spatstat"))
@@ -50,7 +51,7 @@ nbugssince <- nrow(news(Version > "1.42-0" & grepl("^BUG", Category),
 
 
 ###################################################
-### code chunk number 6: updates.Rnw:1260-1261 (eval = FALSE)
+### code chunk number 6: updates.Rnw:1400-1401 (eval = FALSE)
 ###################################################
 ## news(grepl("^BUG", Category), package="spatstat")
 
